Examples
========

No potential
------------

.. literalinclude:: ../../examples/01_zero_potential.py
   :language: python

Quadratic potential
-------------------

.. literalinclude:: ../../examples/02_quadratic_potential.py
   :language: python

2D system
---------

.. literalinclude:: ../../examples/03_2D_potential.py
   :language: python

Adiabatic evolution
-------------------

.. literalinclude:: ../../examples/04_adiabatic_evolution.py
   :language: python

Temporal evolution
------------------

.. literalinclude:: ../../examples/05_temporal_evolution.py
   :language: python

Temporal evolution of a 2D system
---------------------------------

.. literalinclude:: ../../examples/06_2D_temporal_evolution.py
   :language: python

Hydrogen atom
---------------------------------

.. literalinclude:: ../../examples/07_hydrogen_atom.py
   :language: python
